[dpdk-dev] [PATCH 09/15] app: replace references to master/slave

Stephen Hemminger stephen at networkplumber.org
Fri Sep 11 21:06:55 CEST 2020


For the miscellaneous tests.  Replace references to master lcore with
main lcore and slave lcore with worker lcore.

Signed-off-by: Stephen Hemminger <sthemmin at microsoft.com>
---
 app/test-acl/main.c              |  2 +-
 app/test-bbdev/test_bbdev_perf.c |  8 ++++----
 app/test-compress-perf/main.c    |  8 ++++----
 app/test-crypto-perf/main.c      | 14 +++++++-------
 app/test-flow-perf/main.c        |  2 +-
 app/test-pipeline/main.c         |  4 ++--
 app/test-sad/main.c              |  4 ++--
 7 files changed, 21 insertions(+), 21 deletions(-)

diff --git a/app/test-acl/main.c b/app/test-acl/main.c
index 0a5dfb621d5e..72ff26674dac 100644
--- a/app/test-acl/main.c
+++ b/app/test-acl/main.c
@@ -1085,7 +1085,7 @@ main(int argc, char **argv)
 	if (config.trace_file != NULL)
 		tracef_init();
 
-	RTE_LCORE_FOREACH_SLAVE(lcore)
+	RTE_LCORE_FOREACH_WORKER(lcore)
 		 rte_eal_remote_launch(search_ip5tuples, NULL, lcore);
 
 	search_ip5tuples(NULL);
diff --git a/app/test-compress-perf/main.c b/app/test-compress-perf/main.c
index ed21605d89c2..cc9951a9b107 100644
--- a/app/test-compress-perf/main.c
+++ b/app/test-compress-perf/main.c
@@ -389,7 +389,7 @@ main(int argc, char **argv)
 	i = 0;
 	uint8_t qp_id = 0, cdev_index = 0;
 
-	RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+	RTE_LCORE_FOREACH_WORKER(lcore_id) {
 
 		if (i == total_nb_qps)
 			break;
@@ -413,7 +413,7 @@ main(int argc, char **argv)
 	while (test_data->level <= test_data->level_lst.max) {
 
 		i = 0;
-		RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+		RTE_LCORE_FOREACH_WORKER(lcore_id) {
 
 			if (i == total_nb_qps)
 				break;
@@ -424,7 +424,7 @@ main(int argc, char **argv)
 			i++;
 		}
 		i = 0;
-		RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+		RTE_LCORE_FOREACH_WORKER(lcore_id) {
 
 			if (i == total_nb_qps)
 				break;
@@ -449,7 +449,7 @@ main(int argc, char **argv)
 
 	case ST_DURING_TEST:
 		i = 0;
-		RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+		RTE_LCORE_FOREACH_WORKER(lcore_id) {
 			if (i == total_nb_qps)
 				break;
 
diff --git a/app/test-crypto-perf/main.c b/app/test-crypto-perf/main.c
index 8f8e580e4dc6..1b54f0902aee 100644
--- a/app/test-crypto-perf/main.c
+++ b/app/test-crypto-perf/main.c
@@ -594,7 +594,7 @@ main(int argc, char **argv)
 
 	i = 0;
 	uint8_t qp_id = 0, cdev_index = 0;
-	RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+	RTE_LCORE_FOREACH_WORKER(lcore_id) {
 
 		if (i == total_nb_qps)
 			break;
@@ -658,7 +658,7 @@ main(int argc, char **argv)
 				distribution_total[buffer_size_count - 1];
 
 		i = 0;
-		RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+		RTE_LCORE_FOREACH_WORKER(lcore_id) {
 
 			if (i == total_nb_qps)
 				break;
@@ -668,7 +668,7 @@ main(int argc, char **argv)
 			i++;
 		}
 		i = 0;
-		RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+		RTE_LCORE_FOREACH_WORKER(lcore_id) {
 
 			if (i == total_nb_qps)
 				break;
@@ -688,7 +688,7 @@ main(int argc, char **argv)
 
 		while (opts.test_buffer_size <= opts.max_buffer_size) {
 			i = 0;
-			RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+			RTE_LCORE_FOREACH_WORKER(lcore_id) {
 
 				if (i == total_nb_qps)
 					break;
@@ -698,7 +698,7 @@ main(int argc, char **argv)
 				i++;
 			}
 			i = 0;
-			RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+			RTE_LCORE_FOREACH_WORKER(lcore_id) {
 
 				if (i == total_nb_qps)
 					break;
@@ -722,7 +722,7 @@ main(int argc, char **argv)
 	}
 
 	i = 0;
-	RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+	RTE_LCORE_FOREACH_WORKER(lcore_id) {
 
 		if (i == total_nb_qps)
 			break;
@@ -742,7 +742,7 @@ main(int argc, char **argv)
 
 err:
 	i = 0;
-	RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+	RTE_LCORE_FOREACH_WORKER(lcore_id) {
 		if (i == total_nb_qps)
 			break;
 
diff --git a/app/test-flow-perf/main.c b/app/test-flow-perf/main.c
index 3589b316f9eb..b9fc3c02f744 100644
--- a/app/test-flow-perf/main.c
+++ b/app/test-flow-perf/main.c
@@ -1103,7 +1103,7 @@ main(int argc, char **argv)
 
 	if (enable_fwd) {
 		init_lcore_info();
-		rte_eal_mp_remote_launch(start_forwarding, NULL, CALL_MASTER);
+		rte_eal_mp_remote_launch(start_forwarding, NULL, CALL_MAIN);
 	}
 
 	RTE_ETH_FOREACH_DEV(port) {
diff --git a/app/test-pipeline/main.c b/app/test-pipeline/main.c
index 7f0d6d3f1862..c8ee4e8927a4 100644
--- a/app/test-pipeline/main.c
+++ b/app/test-pipeline/main.c
@@ -66,8 +66,8 @@ main(int argc, char **argv)
 	app_init();
 
 	/* Launch per-lcore init on every lcore */
-	rte_eal_mp_remote_launch(app_lcore_main_loop, NULL, CALL_MASTER);
-	RTE_LCORE_FOREACH_SLAVE(lcore) {
+	rte_eal_mp_remote_launch(app_lcore_main_loop, NULL, CALL_MAIN);
+	RTE_LCORE_FOREACH_WORKER(lcore) {
 		if (rte_eal_wait_lcore(lcore) < 0)
 			return -1;
 	}
diff --git a/app/test-sad/main.c b/app/test-sad/main.c
index b01e84c570bb..e9c26e741621 100644
--- a/app/test-sad/main.c
+++ b/app/test-sad/main.c
@@ -657,11 +657,11 @@ main(int argc, char **argv)
 
 	add_rules(sad, 10);
 	if (config.parallel_lookup)
-		rte_eal_mp_remote_launch(lookup, sad, SKIP_MASTER);
+		rte_eal_mp_remote_launch(lookup, sad, SKIP_MAIN);
 
 	lookup(sad);
 	if (config.parallel_lookup)
-		RTE_LCORE_FOREACH_SLAVE(lcore_id)
+		RTE_LCORE_FOREACH_WORKER(lcore_id)
 			if (rte_eal_wait_lcore(lcore_id) < 0)
 				return -1;
 
diff --git a/app/test-bbdev/test_bbdev_perf.c b/app/test-bbdev/test_bbdev_perf.c
index 45c0d62acabc..f82abe959cfe 100644
--- a/app/test-bbdev/test_bbdev_perf.c
+++ b/app/test-bbdev/test_bbdev_perf.c
@@ -3658,7 +3658,7 @@ bler_test(struct active_device *ad,
 	t_params[0].queue_id = ad->queue_ids[used_cores++];
 	t_params[0].iter_count = 0;
 
-	RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+	RTE_LCORE_FOREACH_WORKER(lcore_id) {
 		if (used_cores >= num_lcores)
 			break;
 
@@ -3776,7 +3776,7 @@ throughput_test(struct active_device *ad,
 	t_params[0].queue_id = ad->queue_ids[used_cores++];
 	t_params[0].iter_count = 0;
 
-	RTE_LCORE_FOREACH_SLAVE(lcore_id) {
+	RTE_LCORE_FOREACH_WORKER(lcore_id) {
 		if (used_cores >= num_lcores)
 			break;
 
@@ -3817,7 +3817,7 @@ throughput_test(struct active_device *ad,
 	/* In interrupt TC we need to wait for the interrupt callback to deqeue
 	 * all pending operations. Skip waiting for queues which reported an
 	 * error using processing_status variable.
-	 * Wait for master lcore operations.
+	 * Wait for main lcore operations.
 	 */
 	tp = &t_params[0];
 	while ((rte_atomic16_read(&tp->nb_dequeued) <
@@ -3830,7 +3830,7 @@ throughput_test(struct active_device *ad,
 	tp->mbps /= TEST_REPETITIONS;
 	ret |= (int)rte_atomic16_read(&tp->processing_status);
 
 	/* Wait for slave lcores operations */
 	for (used_cores = 1; used_cores < num_lcores; used_cores++) {
 		tp = &t_params[used_cores];
 
@@ -3830,7 +3830,7 @@ throughput_test(struct active_device *ad,
 	ret |= (int)rte_atomic16_read(&tp->processing_status);
 
-	/* Wait for slave lcores operations */
+	/* Wait for worker lcores operations */
 	for (used_cores = 1; used_cores < num_lcores; used_cores++) {
 		tp = &t_params[used_cores];
-- 
2.27.0



More information about the dev mailing list